@@ -31,8 +31,10 @@
 #include "pbd/strsplit.h"
 
 #include <glibmm/miscutils.h>
+#include <glibmm/fileutils.h>
 
 #include "evoral/Control.hpp"
+#include "evoral/evoral/SMF.hpp"
 
 #include "ardour/event_type_map.h"
 #include "ardour/midi_model.h"
@@ -47,6 +49,7 @@
 using namespace ARDOUR;
 using namespace Glib;
 using namespace PBD;
+using namespace Evoral;
 
 /** Constructor used for new internal-to-session files.  File cannot exist. */
 SMFSource::SMFSource (Session& s, const string& path, Source::Flag flags)
@@ -61,9 +64,14 @@ SMFSource::SMFSource (Session& s, const string& path, Source::Flag flags)
 {
 	/* note that origin remains empty */
 
-	if (init(_path, false)) {
+	if (init (_path, false)) {
 		throw failed_constructor ();
 	}
+ 
+        assert (!Glib::file_test (_path, Glib::FILE_TEST_EXISTS));
+	existence_check ();
+
+	_flags = Source::Flag (_flags | Empty);
 
 	/* file is not opened until write */
 
@@ -71,9 +79,42 @@ SMFSource::SMFSource (Session& s, const string& path, Source::Flag flags)
 		return;
 	}
 
-	if (open(_path)) {
+	if (open (_path)) {
 		throw failed_constructor ();
 	}
+
+	_open = true;
+}
+
+/** Constructor used for external-to-session files.  File must exist. */
+SMFSource::SMFSource (Session& s, const string& path)
+	: Source(s, DataType::MIDI, path, Source::Flag (0))
+	, MidiSource(s, path, Source::Flag (0))
+	, FileSource(s, DataType::MIDI, path, string(), Source::Flag (0))
+	, Evoral::SMF()
+	, _last_ev_time_beats(0.0)
+	, _last_ev_time_frames(0)
+	, _smf_last_read_end (0)
+	, _smf_last_read_time (0)
+{
+	/* note that origin remains empty */
+
+	if (init (_path, true)) {
+		throw failed_constructor ();
+	}
+ 
+        assert (Glib::file_test (_path, Glib::FILE_TEST_EXISTS));
+	existence_check ();
+
+	if (_flags & Writable) {
+		/* file is not opened until write */
+		return;
+	}
+
+	if (open (_path)) {
+		throw failed_constructor ();
+	}
+
 	_open = true;
 }
 
@@ -91,8 +132,49 @@ SMFSource::SMFSource (Session& s, const XMLNode& node, bool must_exist)
 		throw failed_constructor ();
 	}
 
-	if (init(_path, true)) {
-		throw failed_constructor ();
+	/* we expect the file to exist, but if no MIDI data was ever added
+	   it will have been removed at last session close. so, we don't
+	   require it to exist if it was marked Empty.
+	*/
+
+	try {
+
+		if (init (_path, true)) {
+			throw failed_constructor ();
+		}
+
+	} catch (MissingSource& err) {
+
+		if (_flags & Source::Empty) {
+			/* we don't care that the file was not found, because
+			   it was empty. But FileSource::init() will have
+			   failed to set our _path correctly, so we have to do
+			   this ourselves. Use the first entry in the search
+			   path for MIDI files, which is assumed to be the
+			   correct "main" location.
+			*/
+			std::vector<Glib::ustring> sdirs;
+			split (s.source_search_path (DataType::MIDI), sdirs, ':');
+			if (sdirs.empty()) {
+				fatal << _("Empty MIDI source search path!") << endmsg;
+				/*NOTREACHED*/
+			}
+			_path = Glib::build_filename (sdirs.front(), _path);
+			/* This might be important, too */
+			_file_is_new = true;
+		} else {
+			/* pass it on */
+			throw;
+		}
+	}
+
+	if (!(_flags & Source::Empty)) {
+		assert (Glib::file_test (_path, Glib::FILE_TEST_EXISTS));
+		existence_check ();
+	} else {
+		assert (_flags & Source::Writable);
+		/* file will be opened on write */
+		return;
 	}
 
 	if (open(_path)) {
@@ -336,6 +418,7 @@ SMFSource::append_event_unlocked_beats (const Evoral::Event<double>& ev)
 
 	Evoral::SMF::append_event_delta(delta_time_ticks, ev.size(), ev.buffer(), event_id);
 	_last_ev_time_beats = ev.time();
+	_flags = Source::Flag (_flags & ~Empty);
 }
 
 /** Append an event with a timestamp in frames (framepos_t) */
@@ -382,6 +465,7 @@ SMFSource::append_event_unlocked_frames (const Evoral::Event<framepos_t>& ev, fr
 
 	Evoral::SMF::append_event_delta(delta_time_ticks, ev.size(), ev.buffer(), event_id);
 	_last_ev_time_frames = ev.time();
+	_flags = Source::Flag (_flags & ~Empty);
 }
 
 XMLNode&
@@ -455,6 +539,15 @@ SMFSource::mark_midi_streaming_write_completed (Evoral::Sequence<Evoral::Musical
 	mark_nonremovable ();
 }
 
+bool
+SMFSource::valid_midi_file (const string& file)
+{
+	if (safe_midi_file_extension (file) ) {
+		return (SMF::test (file) );
+	}
+	return false;
+}
+
 bool
 SMFSource::safe_midi_file_extension (const string& file)
 {
@@ -463,7 +556,14 @@ SMFSource::safe_midi_file_extension (const string& file)
 	const int nmatches = 2;
 	regmatch_t matches[nmatches];
 	
-	if (compile && regcomp (&compiled_pattern, "[mM][iI][dD][iI]?$", REG_EXTENDED)) {
+	if (Glib::file_test (file, Glib::FILE_TEST_EXISTS)) {
+		if (!Glib::file_test (file, Glib::FILE_TEST_IS_REGULAR)) {
+			/* exists but is not a regular file */
+			return false;
+		}
+	}
+
+	if (compile && regcomp (&compiled_pattern, "\\.[mM][iI][dD][iI]?$", REG_EXTENDED)) {
 		return false;
 	} else {
 		compile = false;
@@ -608,10 +708,12 @@ SMFSource::destroy_model ()
 void
 SMFSource::flush_midi ()
 {
-	if (!writable() || (writable() && !_open)) {
+	if (!writable() || _length_beats == 0.0) {
 		return;
 	}
 
+	ensure_disk_file ();
+
 	Evoral::SMF::end_write ();
 	/* data in the file means its no longer removable */
 	mark_nonremovable ();
@@ -628,6 +730,10 @@ SMFSource::set_path (const string& p)
 void
 SMFSource::ensure_disk_file ()
 {
+	if (!writable()) {
+		return;
+	}
+
 	if (_model) {
 		/* We have a model, so write it to disk; see MidiSource::session_saved
 		   for an explanation of what we are doing here.
@@ -643,9 +749,16 @@ SMFSource::ensure_disk_file ()
 		if (!_open) {
 			open_for_write ();
 		}
-
-		/* Flush, which will definitely put something on disk */
-		flush_midi ();
 	}
 }
 
+void
+SMFSource::prevent_deletion ()
+{
+	/* Unlike the audio case, the MIDI file remains mutable (because we can
+	   edit MIDI data)
+	*/
+  
+	_flags = Flag (_flags & ~(Removable|RemovableIfEmpty|RemoveAtDestroy));
+}
+
